==> jc-1.4.0.tar.gz: org/dellroad/jc/BootstrapObjectGenerator__24SearchpathMatcher.h <==
// abstract class org.dellroad.jc.BootstrapObjectGenerator$SearchpathMatcher

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 25215c5cc24f2d81 org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object;

typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern _jc_object_array *_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$getMatches$08126a5d9b4c83f5(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$getMatches$65d62d43654fc8a6(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, jint);
extern jboolean _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$isMatch$a6e70104319ef91a(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$getMatches$08126a5d9b4c83f5;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$getMatches$65d62d43654fc8a6;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$isMatch$a6e70104319ef91a;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods {
	_jc_object_array	*(*getMatches$08126a5d9b4c83f5)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *);
	struct _jc_object	*(*getMatches$65d62d43654fc8a6)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, jint);
	jboolean	(*isMatch$a6e70104319ef91a)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *);
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/BootstrapObjectGenerator__24SearchpathMatcher.h <==
// abstract class org.dellroad.jc.BootstrapObjectGenerator$SearchpathMatcher

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 25215c5cc24f2d81 org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object;

typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$getMatches$08126a5d9b4c83f5(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$getMatches$65d62d43654fc8a6(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$isMatch$a6e70104319ef91a(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$getMatches$08126a5d9b4c83f5;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$getMatches$65d62d43654fc8a6;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$isMatch$a6e70104319ef91a;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods {
	_jc_object_array	*(*getMatches$08126a5d9b4c83f5)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getMatches$65d62d43654fc8a6)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*isMatch$a6e70104319ef91a)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs {
	struct _jc_java_lang_String$object	*name;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher_H_ */
